<?php
/**
 * Client Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Client section
$wp_customize->add_section( 'chrisporate_pro_client_section', array(
	'title'             => esc_html__( 'Client Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Client Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Client content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_section_enable]', array(
	'default'			=> 	$options['client_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'Client Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_client_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Client content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_content_type]', array(
	'default'          	=> $options['client_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[client_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_client_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_client_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'category' 	=> esc_html__( 'Category', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
	),
) );

// Client number control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_count]', array(
	'default'          	=> $options['client_count'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_number_range',
	'validate_callback' => 'chrisporate_pro_validate_client_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[client_count]', array(
	'label'             => esc_html__( 'Number of Client', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_client_section',
	'active_callback'   => 'chrisporate_pro_is_client_section_count_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Client Section content type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_content_post]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[client_content_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_client_section_content_post_enable',
	'label'             => esc_html__( 'Input Post Ids', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 10. ie: 11, 24, 34', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_client_section',
	'type'				=> 'text',
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'chrisporate_pro_theme_options[client_content_category]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Chrisporate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'chrisporate_pro_theme_options[client_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'chrisporate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_client_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'chrisporate_pro_is_client_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['client_count']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_content_page_' . $i . ']', array(
		'sanitize_callback' => 'chrisporate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[client_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_client_section',
		'active_callback' 	=> 'chrisporate_pro_is_client_section_content_page_enable',
		'type'				=> 'dropdown-pages'
	) );

	// Client hr setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_section_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[client_section_hr_' . $i . ']',
		array(
			'section'         => 'chrisporate_pro_client_section',
			'active_callback' => 'chrisporate_pro_is_client_section_content_custom_enable',
			'type'			  => 'hr'
	) ) );

	// Client additional image setting and control.
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_image_' . $i . ']', array(
		'default' 			=> $options['client_image'],
		'sanitize_callback' => 'chrisporate_pro_sanitize_image',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'chrisporate_pro_theme_options[client_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Select Image %d', 'chrisporate-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'chrisporate-pro' ), 144, 144 ),
			'section'     		=> 'chrisporate_pro_client_section',
			'active_callback'	=> 'chrisporate_pro_is_client_section_content_custom_enable',
	) ) );

	// client title setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['client_title'],
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[client_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_client_section',
		'active_callback' 	=> 'chrisporate_pro_is_client_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// client link setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[client_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'          	=> '#',
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[client_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Link %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_client_section',
		'active_callback' 	=> 'chrisporate_pro_is_client_section_content_custom_enable',
		'type'				=> 'url',
	) );

}
