<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'chrisporate_pro_contact_section', array(
	'title'             => esc_html__( 'Contact Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Contact Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_contact_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Contact content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_title_type]', array(
	'default'          	=> $options['contact_title_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_title_type]', array(
	'label'             => esc_html__( 'Title Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_contact_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_title_page]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_page'
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_title_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_title_page_enable',
	'type'				=> 'dropdown-pages'
) );

// Contact Section content type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_title_post]', array(
	'validate_callback' => 'chrisporate_pro_validate_post_id',
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_title_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_contact_section_title_post_enable',
	'label'             => esc_html__( 'Input Post Id', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_contact_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Contact title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_title_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[contact_title]', array(
		'selector'            => '#contact-form .container .find-us-content-title .entry-header h2.entry-title',
		'settings'            => 'chrisporate_pro_theme_options[contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_contact_title_partial',
    ) );
}

// Contact description setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['contact_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_description]', array(
	'label'           	=> esc_html__( 'Description', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_title_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[contact_description]', array(
		'selector'            => '#contact-form .container .find-us-content-title p.description',
		'settings'            => 'chrisporate_pro_theme_options[contact_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_contact_description_partial',
    ) );
}

// Contact hr setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_section_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[contact_section_hr]',
	array(
		'section'         => 'chrisporate_pro_contact_section',
		'active_callback' => 'chrisporate_pro_is_contact_section_enable',
		'type'			  => 'hr'
) ) );


// Contact title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_address]', array(
	'default' 			=> $options['contact_address'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_address]', array(
	'label'           	=> esc_html__( 'Full Address', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[contact_address]', array(
		'selector'            => '#contact-form .container .entry-content .address-block .address span',
		'settings'            => 'chrisporate_pro_theme_options[contact_address]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_contact_address_partial',
    ) );
}

// contact phone repeater control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_phone]', array(
	'default' 			=> $options['contact_phone'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Chrisporate_Pro_Multi_Input_Custom_Control( $wp_customize, 'chrisporate_pro_theme_options[contact_phone]', array(
	'label'             => esc_html__( 'Phone No', 'chrisporate-pro' ),
	'button_text'       => esc_html__( 'Add Phone No.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_enable',
) ) );

// contact email repeater control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_email]', array(
	'default' 			=> $options['contact_email'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Chrisporate_Pro_Multi_Input_Custom_Control( $wp_customize, 'chrisporate_pro_theme_options[contact_email]', array(
	'label'             => esc_html__( 'Email Id', 'chrisporate-pro' ),
	'button_text'       => esc_html__( 'Add Email Id', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_enable',
) ) );


// Contact form setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[contact_form]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[contact_form]', array(
	'label'           	=> esc_html__( 'Contact Form Shortcode', 'chrisporate-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( 'https://wordpress.org/plugins/contact-form-7/' ) .'" target="_blank"> %2$s </a> %3$s', esc_html__( 'Input shortcode from Contact Form 7 Plugin', 'chrisporate-pro' ), esc_html__( 'Click Here', 'chrisporate-pro' ), esc_html__( 'to download plugin.', 'chrisporate-pro' ) ),
	'section'        	=> 'chrisporate_pro_contact_section',
	'active_callback' 	=> 'chrisporate_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

