<?php
/**
 * Portfolio Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Portfolio section
$wp_customize->add_section( 'chrisporate_pro_portfolio_section', array(
	'title'             => esc_html__( 'Portfolio Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Portfolio Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Portfolio content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_section_enable]', array(
	'default'			=> 	$options['portfolio_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[portfolio_section_enable]', array(
	'label'             => esc_html__( 'Portfolio Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_title_type]', array(
	'default'          	=> $options['portfolio_title_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_title_type]', array(
	'label'             => esc_html__( 'Title Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_title_page]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_page'
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_title_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_portfolio_section',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_title_page_enable',
	'type'				=> 'dropdown-pages'
) );

// Portfolio Section title type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_title_post]', array(
	'validate_callback' => 'chrisporate_pro_validate_post_id',
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_title_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_portfolio_section_title_post_enable',
	'label'             => esc_html__( 'Input Post Id', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Portfolio title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['portfolio_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_title]', array(
	'label'           	=> esc_html__( 'Title', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_portfolio_section',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_title_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[portfolio_title]', array(
		'selector'            => '#portfolio .container .portfolio-content-title .entry-header h2.entry-title',
		'settings'            => 'chrisporate_pro_theme_options[portfolio_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_portfolio_title_partial',
    ) );
}

// Portfolio description setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['portfolio_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_description]', array(
	'label'           	=> esc_html__( 'Description', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_portfolio_section',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_title_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[portfolio_description]', array(
		'selector'            => '#portfolio .container .portfolio-content-title p.description',
		'settings'            => 'chrisporate_pro_theme_options[portfolio_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_portfolio_description_partial',
    ) );
}

// Portfolio hr setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_section_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[portfolio_section_hr]',
	array(
		'section'         => 'chrisporate_pro_portfolio_section',
		'active_callback' => 'chrisporate_pro_is_portfolio_section_enable',
		'type'			  => 'hr'
) ) );

// Portfolio content layout control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_section_layout]', array(
	'default'          	=> $options['portfolio_section_layout'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_section_layout]', array(
	'label'             => esc_html__( 'Layout', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'col-2' 	=> esc_html__( 'Two Column', 'chrisporate-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'chrisporate-pro' ),
	),
) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_content_type]', array(
	'default'          	=> $options['portfolio_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'category' 	=> esc_html__( 'Category', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_count]', array(
	'default'          	=> $options['portfolio_count'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_number_range',
	'validate_callback' => 'chrisporate_pro_validate_portfolio_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_count]', array(
	'label'             => esc_html__( 'Number of Portfolio', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'active_callback'   => 'chrisporate_pro_is_portfolio_section_count_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Portfolio Section content type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_content_post]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_content_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_portfolio_section_content_post_enable',
	'label'             => esc_html__( 'Input Post Ids', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 12. ie: 11, 24, 34', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'text',
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'chrisporate_pro_theme_options[portfolio_content_category]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Chrisporate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'chrisporate_pro_theme_options[portfolio_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'chrisporate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'chrisporate_pro_is_portfolio_section_content_category_enable'
) ) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_load_more]', array(
	'default'          	=> $options['portfolio_load_more'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_load_more]', array(
	'label'             => esc_html__( 'Load More Option', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_portfolio_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_content_category_enable',
	'choices'			=> array( 
		'ajax' 		=> esc_html__( 'Ajax Load', 'chrisporate-pro' ),
		'link' 		=> esc_html__( 'Category Link', 'chrisporate-pro' ),
	),
) );

// Portfolio loadmore btn label setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['portfolio_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_portfolio_section',
	'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_content_category_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[portfolio_btn_label]', array(
		'selector'            => '#portfolio #Ploadmore',
		'settings'            => 'chrisporate_pro_theme_options[portfolio_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_portfolio_btn_label_partial',
    ) );
}

for ( $i = 1; $i <= $options['portfolio_count']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'sanitize_callback' => 'chrisporate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_portfolio_section',
		'active_callback' 	=> 'chrisporate_pro_is_portfolio_section_content_page_enable',
		'type'				=> 'dropdown-pages'
	) );
}
