<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'chrisporate_pro_team_section', array(
	'title'             => esc_html__( 'Team Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Team content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_title_type]', array(
	'default'          	=> $options['team_title_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_title_type]', array(
	'label'             => esc_html__( 'Title Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_team_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_title_page]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_page'
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_title_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_team_section',
	'active_callback' 	=> 'chrisporate_pro_is_team_section_title_page_enable',
	'type'				=> 'dropdown-pages'
) );

// Team Section title type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_title_post]', array(
	'validate_callback' => 'chrisporate_pro_validate_post_id',
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_title_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_team_section_title_post_enable',
	'label'             => esc_html__( 'Input Post Id', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Team title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_team_section',
	'active_callback' 	=> 'chrisporate_pro_is_team_section_title_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[team_title]', array(
		'selector'            => '#team .container .team-content-title .entry-header h2.entry-title',
		'settings'            => 'chrisporate_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_team_title_partial',
    ) );
}

// Team description setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['team_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_description]', array(
	'label'           	=> esc_html__( 'Description', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_team_section',
	'active_callback' 	=> 'chrisporate_pro_is_team_section_title_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[team_description]', array(
		'selector'            => '#team .container .team-content-title p.description',
		'settings'            => 'chrisporate_pro_theme_options[team_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_team_description_partial',
    ) );
}

// Team hr setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_section_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[team_section_hr]',
	array(
		'section'         => 'chrisporate_pro_team_section',
		'active_callback' => 'chrisporate_pro_is_team_section_enable',
		'type'			  => 'hr'
) ) );


// Team content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_team_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'category' 	=> esc_html__( 'Category', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
		'custom'	=> esc_html__( 'custom', 'chrisporate-pro' ),
	),
) );


// Team Section content type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_content_post]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[team_content_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_team_section_content_post_enable',
	'label'             => esc_html__( 'Input Post Ids', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 3. ie: 11, 24, 34', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'type'				=> 'text',
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'chrisporate_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Chrisporate_Pro_Dropdown_Taxonomies_Control( $wp_customize,'chrisporate_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'chrisporate-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'chrisporate_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= 3; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'chrisporate_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_team_section',
		'active_callback' 	=> 'chrisporate_pro_is_team_section_content_page_enable',
		'type'				=> 'dropdown-pages'
	) );

	// Team hr setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_section_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[team_section_hr_' . $i . ']',
		array(
			'section'         => 'chrisporate_pro_team_section',
			'active_callback' => 'chrisporate_pro_is_team_section_content_custom_enable',
			'type'			  => 'hr'
	) ) );

	// Team title setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['team_title'],
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[team_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_team_section',
		'active_callback' 	=> 'chrisporate_pro_is_team_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// Team Subtitle setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['team_sub_title'],
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[team_sub_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sub Title %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_team_section',
		'active_callback' 	=> 'chrisporate_pro_is_team_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// Team quote setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_quote_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['team_quote'],
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[team_quote_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Quote/Short Note %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_team_section',
		'active_callback' 	=> 'chrisporate_pro_is_team_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// Team description setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'          	=> $options['team_description'],
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[team_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_team_section',
		'active_callback' 	=> 'chrisporate_pro_is_team_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// Testimonial additional image setting and control.
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[team_image_' . $i . ']', array(
		'default' 			=> $options['team_image'],
		'sanitize_callback' => 'chrisporate_pro_sanitize_image',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'chrisporate_pro_theme_options[team_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Select Image %d', 'chrisporate-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'chrisporate-pro' ), 353, 469 ),
			'section'     		=> 'chrisporate_pro_team_section',
			'active_callback'	=> 'chrisporate_pro_is_team_section_content_custom_enable',
	) ) );

}
