<?php
/**
 * Theme Palace custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Photo Fusion Pro
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

if( ! function_exists( 'chrisporate_pro_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
  	function chrisporate_pro_check_enable_status( $input, $content_enable ){
		$options = chrisporate_pro_get_theme_options();

		// Content status.
		$content_status = $options[ $content_enable ];

		if ( ( ! is_home() && is_front_page() ) && $content_status ) {
			$input = true;
		}
		else {
			$input = false;
		}
		
		return $input;
  	}
endif;
add_filter( 'chrisporate_pro_section_status', 'chrisporate_pro_check_enable_status', 10, 2 );


if ( ! function_exists( 'chrisporate_pro_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_is_sidebar_enable() {
		$options               = chrisporate_pro_get_theme_options();
		$sidebar_position      = $options['sidebar_position'];

		if ( is_home() ) {
			$post_id = get_option( 'page_for_posts' );
			if ( ! empty( $post_id ) )
				$post_sidebar_position = get_post_meta( $post_id, 'chrisporate-pro-sidebar-position', true );
			else
				$post_sidebar_position = '';
		} elseif ( is_archive() || is_search() ) {
			$post_sidebar_position = '';
		} else {
			$post_id = get_the_id();
			$post_sidebar_position = get_post_meta( $post_id, 'chrisporate-pro-sidebar-position', true );
		}
		if ( ( in_array( $sidebar_position, array( 'no-sidebar', 'no-sidebar-content' ) ) && $post_sidebar_position == "" ) || in_array( $post_sidebar_position, array( 'no-sidebar', 'no-sidebar-content' ) ) ) {
			return false;
		} else {
			return true;
		}

	}
endif;

if ( ! function_exists( 'chrisporate_pro_single_header_image' ) ) :
	/**
	 * Check the post/page header image option
	 *
	 */
	function chrisporate_pro_single_header_image() {
		$header_image = get_post_meta( get_the_id(), 'chrisporate-pro-header-image', true );
		$header_image = ! empty( $header_image ) ? $header_image : 'show-both';
		return $header_image;
	}

endif;


if ( ! function_exists( 'chrisporate_pro_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function chrisporate_pro_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = chrisporate_pro_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}

endif;

add_filter( 'chrisporate_pro_filter_frontpage_content_enable', 'chrisporate_pro_is_frontpage_content_enable' );


add_action( 'chrisporate_pro_simple_breadcrumb', 'chrisporate_pro_simple_breadcrumb' , 10 );
if ( ! function_exists( 'chrisporate_pro_simple_breadcrumb' ) ) :

	/**
	 * Simple breadcrumb.
	 *
	 * @param  array $args Arguments
	 */
	function chrisporate_pro_simple_breadcrumb( $args = array() ) {

		/**
		 * Add breadcrumb.
		 *
		 */
		$options = chrisporate_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}

		$args = array(
			'show_on_front'   => false,
			'show_title'      => true,
			'show_browse'     => false,
		);
		breadcrumb_trail( $args );      

		return;
	}

endif;


add_action( 'chrisporate_pro_action_pagination', 'chrisporate_pro_pagination', 10 );
if ( ! function_exists( 'chrisporate_pro_pagination' ) ) :

	/**
	 * pagination.
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_pagination() {
		$options = chrisporate_pro_get_theme_options();
		if ( true == $options['pagination_enable'] ) {
			$pagination = $options['pagination_type'];
			if ( $pagination == 'default' ) :
				the_posts_navigation();
			elseif ( in_array( $pagination, array( 'infinite', 'numeric' ) ) ) :
				the_posts_pagination( array(
				    'mid_size' => 4,
				    'prev_text' => esc_html__( 'Previous', 'chrisporate-pro' ),
				    'next_text' => esc_html__( 'Next', 'chrisporate-pro' ),
				) );
			endif;
		}
	}

endif;


add_action( 'chrisporate_pro_action_post_pagination', 'chrisporate_pro_post_pagination', 10 );
if ( ! function_exists( 'chrisporate_pro_post_pagination' ) ) :

	/**
	 * post pagination.
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_post_pagination() {
		$options = chrisporate_pro_get_theme_options();
		if ( true === $options['single_post_show_pagination'] ) {
			the_post_navigation();
		} 
	}
endif;


if ( ! function_exists( 'chrisporate_pro_excerpt_length' ) ) :
	/**
	 * long excerpt
	 * 
	 * @since Chrisporate Pro 1.0.0
	 * @return long excerpt value
	 */
	function chrisporate_pro_excerpt_length( $length ){
		if ( is_admin() ) {
			return $length;
		}

		$options = chrisporate_pro_get_theme_options();
		$length = $options['long_excerpt_length'];
		return $length;
	}
endif;
add_filter( 'excerpt_length', 'chrisporate_pro_excerpt_length', 999 );


if ( ! function_exists( 'chrisporate_pro_excerpt_more' ) ) :
	// Read more
	function chrisporate_pro_excerpt_more( $more ){
		return '...';
	}
endif;
add_filter( 'excerpt_more', 'chrisporate_pro_excerpt_more' );


if ( ! function_exists( 'chrisporate_pro_trim_content' ) ) :
	/**
	 * custom excerpt function
	 * 
	 * @since Chrisporate Pro 1.0.0
	 * @return  no of words to display
	 */
	function chrisporate_pro_trim_content( $length = 40, $post_obj = null ) {
		global $post;
		if ( is_null( $post_obj ) ) {
			$post_obj = $post;
		}

		$length = absint( $length );
		if ( $length < 1 ) {
			$length = 40;
		}

		$source_content = $post_obj->post_content;
		if ( ! empty( $post_obj->post_excerpt ) ) {
			$source_content = $post_obj->post_excerpt;
		}

		$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
		$trimmed_content = wp_trim_words( $source_content, $length, '...' );

	   return apply_filters( 'chrisporate_pro_trim_content', $trimmed_content );
	}
endif;


if ( ! function_exists( 'chrisporate_pro_layout' ) ) :
	/**
	 * Check home page layout option
	 *
	 * @since Chrisporate Pro 1.0.0
	 *
	 * @return string Chrisporate Pro layout value
	 */
	function chrisporate_pro_layout() {
		$options = chrisporate_pro_get_theme_options();

		$sidebar_position = $options['sidebar_position'];
		$sidebar_position = apply_filters( 'chrisporate_pro_sidebar_position', $sidebar_position );
		// Check if single and static blog page
		if ( is_singular() || is_home() ) {
			if ( is_home() ) {
				$post_sidebar_position = get_post_meta( get_option( 'page_for_posts' ), 'chrisporate-pro-sidebar-position', true );
			} else {
				$post_sidebar_position = get_post_meta( get_the_ID(), 'chrisporate-pro-sidebar-position', true );
			}
			if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
				$sidebar_position = $post_sidebar_position;
			}
		}
		return $sidebar_position;
	}
endif;

/**
 * Fallback function call for menu
 * @param  Mixed $args Menu arguments
 * @return String $output Return or echo the add menu link.       
 */
function chrisporate_pro_menu_fallback_cb( $args ){
    if ( ! current_user_can( 'edit_theme_options' ) ){
	    return;
   	}
    // see wp-includes/nav-menu-template.php for available arguments
    $link = $args['link_before']
        	. '<a href="' .esc_url( admin_url( 'nav-menus.php' ) ) . '">' . $args['before'] . esc_html__( 'Add a menu','chrisporate-pro' ) . $args['after'] . '</a>'
        	. $args['link_after'];

   	if ( FALSE !== stripos( $args['items_wrap'], '<ul' ) || FALSE !== stripos( $args['items_wrap'], '<ol' )
	){
		$link = "<li>$link</li>";
	}
	$output = sprintf( $args['items_wrap'], $args['menu_id'], $args['menu_class'], $link );
	if ( ! empty ( $args['container'] ) ){
		$output = sprintf( '<%1$s class="%2$s" id="%3$s">%4$s</%1$s>', $args['container'], $args['container_class'], $args['container_id'], $output );
	}
	if ( $args['echo'] ){
		echo $output;
	}
	return $output;
}


if ( ! function_exists( 'chrisporate_pro_portfolio_ajax_enqueuer' ) ) :
	/**
	 * ajax enquue
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_portfolio_ajax_enqueuer() {
	   	wp_register_script( "chrisporate-pro-ajax", get_template_directory_uri() . '/assets/js/ajax' . chrisporate_pro_min() . '.js', array( 'jquery' ), '', true );
	   	wp_localize_script( 'chrisporate-pro-ajax', 'chrisporate_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );        
	   	wp_enqueue_script( 'chrisporate-pro-ajax' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'chrisporate_pro_portfolio_ajax_enqueuer' );

if ( ! function_exists( 'chrisporate_pro_portfolio_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_portfolio_ajax_handler(){
		$options = chrisporate_pro_get_theme_options();
		$cat_id = ! empty( $options['portfolio_content_category'] ) ? $options['portfolio_content_category'] : '';
		$portfolio_count = ! empty( $options['portfolio_count'] ) ? $options['portfolio_count'] : 4;
	    $page = ( isset( $_POST['pageNumber'] ) ) ? absint( wp_unslash( $_POST['pageNumber'] ) ) : 1;
	    header("Content-Type: text/html");

	    $portfolio_args = array(
	        'post_type' 		=> 'post',
	        'posts_per_page' 	=> $portfolio_count,
	        'cat'      			=> $cat_id,
	        'paged'    			=> $page,
	    );

        $portfolio_posts = new WP_Query( $portfolio_args );
            
        if ( $portfolio_posts -> have_posts() ) : while ( $portfolio_posts -> have_posts() ) : $portfolio_posts -> the_post();
        	$image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-550x382.jpg';
        	?>
          	<div class="hentry">
                <figure>
                    <a href="<?php the_permalink(); ?>">
                        <img src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
                    </a>
                </figure>
                <div class="portfolio-title">
                    <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                    <div class="entry-summary">
                        <p><?php echo esc_html( chrisporate_pro_trim_content( 15 ) ); ?></p>
                    </div>
                </div><!-- .portfolio-title -->
            </div><!-- .hentry -->
        <?php endwhile; endif; 
        wp_reset_postdata();
	    die();
	}
endif;
add_action("wp_ajax_chrisporate_pro_portfolio_ajax_handler", "chrisporate_pro_portfolio_ajax_handler");
add_action("wp_ajax_nopriv_chrisporate_pro_portfolio_ajax_handler", "chrisporate_pro_portfolio_ajax_handler");

if ( ! function_exists( 'chrisporate_pro_latest_blog_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Chrisporate Pro 1.0.0
	 */
	function chrisporate_pro_latest_blog_ajax_handler(){
		$options = chrisporate_pro_get_theme_options();
		$latest_blog_count = ! empty( $options['latest_blog_count'] ) ? $options['latest_blog_count'] : 3;
		$read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'chrisporate-pro' );
	    $page = ( isset( $_POST['LBpageNumber'] ) ) ? absint( wp_unslash( $_POST['LBpageNumber'] ) ) : 1;
	    header("Content-Type: text/html");

	    if ( 'category' == $options['latest_blog_content_type'] ) :
			$cat_id = ! empty( $options['latest_blog_content_category'] ) ? $options['latest_blog_content_category'] : '';
		    $latest_blog_args = array(
		        'post_type' 		=> 'post',
		        'posts_per_page' 	=> $latest_blog_count,
		        'cat'      			=> $cat_id,
		        'paged'    			=> $page,
		    );
		elseif ( 'all' == $options['latest_blog_content_type'] ) :
			$cat_ids = ! empty( $options['latest_blog_exclude_category'] ) ? $options['latest_blog_exclude_category'] : array();
			$latest_blog_args = array(
		        'post_type' 		=> 'post',
		        'posts_per_page' 	=> $latest_blog_count,
		        'category__not_in'  => ( array ) $cat_ids,
                'ignore_sticky_posts'   => true,
		        'paged'    			=> $page,
		    );
		endif;

        $latest_blog_posts = new WP_Query( $latest_blog_args );
            
        if ( $latest_blog_posts -> have_posts() ) : while ( $latest_blog_posts -> have_posts() ) : $latest_blog_posts -> the_post(); 
        	$image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-550x382.jpg';
        	?>
        	 <article class="hentry">
                <?php if ( ! empty( $image ) ) : ?>
                    <div class="featured-image">
                        <a href="<?php the_permalink(); ?>"><img src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"></a>
                    </div><!--.featured-image-->
                <?php endif; ?>

                <div class="entry-container">
                    <div class="entry-meta">
                        <span class="cat-links">
                            <?php the_category( ', '); ?>
                        </span>
                        <span class="byline"><?php esc_html_e( 'BY ', 'chrisporate-pro' ) ?>
                            <span class="author vcard">
                                <?php the_author_posts_link(); ?>
                            </span>
                        </span>
                    </div><!-- .entry-meta -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                    </header>
                   
                    <div class="entry-content">
                        <p><?php echo esc_html( chrisporate_pro_trim_content( 20 ) ); ?></p>

                        <a href="<?php the_permalink(); ?>" class="btn btn-fill"><?php echo esc_html( $read_more ); ?></a>
                    </div><!--.blog-content-->
                </div><!-- .entry-container -->
            </article><!-- #post-1 -->

        <?php endwhile; endif;
        wp_reset_postdata();
	    die();
	}
endif;
add_action("wp_ajax_chrisporate_pro_latest_blog_ajax_handler", "chrisporate_pro_latest_blog_ajax_handler");
add_action("wp_ajax_nopriv_chrisporate_pro_latest_blog_ajax_handler", "chrisporate_pro_latest_blog_ajax_handler");


if ( ! function_exists( 'chrisporate_pro_sort' ) ) :
	/**
	 *
	 * @since Chrisporate Pro 1.0.0
	 *
	 */
	function chrisporate_pro_sort( $section ) {

		if ( empty( $section ) )
			return;

		$options = chrisporate_pro_get_theme_options();
		$choices = chrisporate_pro_sortable_sections();
		$sorted = array();

		if ( ! empty( $options['sortable'] ) ) {
			$sorted = explode( ',' , $options['sortable'] );
		}

		$i = 1;
		foreach ( $sorted as $value ) :
			if ( $choices[$section] == $value )
				return $i . 0;
			$i++;
		endforeach;
	}
endif;
