<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function chrisporate_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'chrisporate_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function chrisporate_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'chrisporate-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'chrisporate-pro' ),
            'header-font-2'   => esc_html__( 'Dynalight', 'chrisporate-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'chrisporate-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'chrisporate-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'chrisporate-pro' ),
        );

        $output = apply_filters( 'chrisporate_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'chrisporate_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function chrisporate_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'chrisporate-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'chrisporate-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'chrisporate-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'chrisporate-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'chrisporate-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'chrisporate-pro' ),
        );

        $output = apply_filters( 'chrisporate_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;

if ( ! function_exists( 'chrisporate_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function chrisporate_pro_site_layout() {
        $chrisporate_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'chrisporate_pro_site_layout', $chrisporate_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'chrisporate_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function chrisporate_pro_sidebar_position() {
        $chrisporate_pro_sidebar_position = array(
            'right-sidebar'         => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'          => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'            => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'    => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'chrisporate_pro_sidebar_position', $chrisporate_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'chrisporate_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function chrisporate_pro_selected_sidebar() {
        $chrisporate_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'chrisporate-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'chrisporate-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'chrisporate-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'chrisporate-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'chrisporate-pro' ),
        );

        $output = apply_filters( 'chrisporate_pro_selected_sidebar', $chrisporate_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'chrisporate_pro_header_image' ) ) :
    /**
     * Header image options
     * @return array header images
     */
    function chrisporate_pro_header_image() {
        $chrisporate_pro_header_image = array(
            'show-both'         => esc_html__( 'Show Both', 'chrisporate-pro' ),
            'header-image'      => esc_html__( 'Customizer Header Image', 'chrisporate-pro' ),
            'featured-image'    => esc_html__( 'Featured Image', 'chrisporate-pro' ),
        );

        $output = apply_filters( 'chrisporate_pro_header_image', $chrisporate_pro_header_image );

        return $output;
    }
endif;


if ( ! function_exists( 'chrisporate_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function chrisporate_pro_pagination_options() {
        $chrisporate_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'chrisporate-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'chrisporate-pro' ),
            'infinite'  => esc_html__( 'Infinite Scroll', 'chrisporate-pro' ),
        );

        $output = apply_filters( 'chrisporate_pro_pagination_options', $chrisporate_pro_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'chrisporate_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function chrisporate_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'chrisporate-pro' ),
            'off'       => esc_html__( 'Disable', 'chrisporate-pro' )
        );
        return apply_filters( 'chrisporate_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'chrisporate_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function chrisporate_pro_sortable_sections() {
        $sections = array(
            'about'         => esc_html__( 'About', 'chrisporate-pro' ),
            'service'       => esc_html__( 'Services', 'chrisporate-pro' ),
            'counter'       => esc_html__( 'Counter', 'chrisporate-pro' ),
            'portfolio'     => esc_html__( 'Portfolio', 'chrisporate-pro' ),
            'author'        => esc_html__( 'Author', 'chrisporate-pro' ),
            'latest_blog'   => esc_html__( 'Latest Blog', 'chrisporate-pro' ),
            'testimonial'   => esc_html__( 'Testimonial', 'chrisporate-pro' ),
            'team'          => esc_html__( 'Team', 'chrisporate-pro' ),
            'client'        => esc_html__( 'Client', 'chrisporate-pro' ),
        );
        return apply_filters( 'chrisporate_pro_sortable_sections', $sections );
    }
endif;