<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_contact_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'chrisporate_pro_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }
        // Get contact section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_contact_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render contact section now.
        chrisporate_pro_render_contact_section( $section_details );
    }
endif;
add_action( 'chrisporate_pro_footer_content', 'chrisporate_pro_add_contact_section', 10 );


if ( ! function_exists( 'chrisporate_pro_get_contact_section_details' ) ) :
    /**
    * contact section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input contact section details.
    */
    function chrisporate_pro_get_contact_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $contact_title_type  = $options['contact_title_type'];
        $content = array();
        switch ( $contact_title_type ) {
            case 'demo':
                $demo['title']      = esc_html__( 'Find Us', 'chrisporate-pro' );
                $demo['excerpt']    = esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' );

                // Push to the main array.
                array_push( $content, $demo );
            break;

            case 'custom':
                $custom['title']        = ! empty( $options['contact_title'] ) ? $options['contact_title'] : '';
                $custom['excerpt']      = ! empty( $options['contact_description'] ) ? $options['contact_description'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['contact_title_page'] ) ? $options['contact_title_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['contact_title_post'] ) ? $options['contact_title_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'post' === $contact_title_type || 'page' === $contact_title_type ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// contact section content details.
add_filter( 'chrisporate_pro_filter_contact_section_details', 'chrisporate_pro_get_contact_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_contact_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();
        $address = ! empty( $options['contact_address'] ) ? $options['contact_address'] : '';
        $phones = ! empty( $options['contact_phone'] ) ? explode( '|', $options['contact_phone'] ) : array();
        $emails = ! empty( $options['contact_email'] ) ? explode( '|', $options['contact_email'] ) : array();
        ?>
        <div id="contact-form" class="page-section relative">
            <div class="container">
                <?php if ( ! empty( $content_details ) ) :
                    foreach ( $content_details as $content ) : ?>
                    <div class="find-us-content-title clear">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header section-title">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header><!-- .entry-header -->
                        <?php endif; 
                        if ( ! empty( $content['excerpt'] ) ) : ?>
                            <p class="description"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- team-content -->
                    <?php endforeach; 
                endif; ?>
                <div class="entry-content">
                    <div class="contact-information-wrapper col-2">
                        <div class="hentry">
                            <ul class="address-block">
                                <?php if ( ! empty( $address ) ) : ?>
                                    <li class="address"><label><?php esc_html_e( 'Address:', 'chrisporate-pro' ); ?></label>
                                        <span><?php echo esc_html( $address ); ?></span>
                                    </li>
                                <?php endif; 
                                
                                if ( ! empty( $phones ) ) : ?>
                                    <li class="phone"><label><?php esc_html_e( 'Call Us:', 'chrisporate-pro' ); ?></label>
                                        <span>
                                            <?php foreach ( $phones as $phone ) : ?>
                                                <a href="tel:<?php echo esc_attr( $phone ); ?>"><?php echo esc_html( $phone ); ?></a>
                                            <?php endforeach; ?>
                                        </span>
                                    </li>
                                <?php endif; 

                                if ( ! empty( $emails ) ) : ?>
                                    <li class="email"><label><?php esc_html_e( 'Email:', 'chrisporate-pro' ); ?></label>
                                        <span>
                                            <?php foreach ( $emails as $email ) : ?>
                                                <a href="mailto:<?php echo esc_attr( $email ); ?>"><?php echo esc_html( $email ); ?></a>
                                            <?php endforeach; ?>
                                        </span>
                                    </li>
                                <?php endif; ?>
                            </ul><!-- .address-block -->
                        </div><!-- .hentry -->

                        <?php if ( ! empty( $options['contact_form'] ) ) : ?>
                            <div class="hentry">
                                <?php echo do_shortcode( wp_kses_post( $options['contact_form'] ) ); ?>
                            </div>
                        <?php endif; ?>
                    </div><!-- .contact-information-wrapper -->
                </div><!-- .entry-content -->
            </div><!-- .container -->
        </div><!-- #contact-form -->
    <?php
    }
endif;